Live preview
============

The `video` sub-command implements live video preview with the :mod:`pymanip.video` classes. Two GUI toolkits are possible: pyqt or opencv. The desired camera and acquisition parameters must be passed as argument on the command line.
